SledMailboxStore

Struct SledMailboxStore 

pub struct SledMailboxStore {
    pub(crate) tree: Tree,
    pub(crate) encryption: Option<StorageEncryption>,
    pub(crate) max_storage_per_user: usize,
}
A MailboxStore implementation using sled for storage.

Fields

tree: Treeencryption: Option<StorageEncryption>max_storage_per_user: usize

Implementations

Source

impl SledMailboxStore

pub fn new( db: Db, encryption: Option<StorageEncryption>, max_storage_per_user: usize, ) -> Result<Self>

Creates a new SledMailboxStore.

Arguments
  • db - The sled::Db instance to use for storage.
  • encryption - The optional StorageEncryption to use for encrypting messages.
  • max_storage_per_user - The maximum number of messages to store per user.
Errors

This function will return an error if the mailbox tree cannot be opened.

pub(crate) fn make_message_key( &self, recipient_hash: &[u8; 32], msg_id: &Uuid, ) -> Vec<u8>

Creates a unique key for a message in the mailbox.

pub(crate) fn serialize_message( &self, msg: &EncryptedMessage, ) -> Result<Vec<u8>>

Serializes an EncryptedMessage and encrypts it if encryption is enabled.

pub(crate) fn deserialize_message( &self, data: &[u8], ) -> Result<EncryptedMessage>

Decrypts and deserializes an EncryptedMessage.