pub struct SledMailboxStore {
pub(crate) tree: Tree,
pub(crate) encryption: Option<StorageEncryption>,
pub(crate) max_storage_per_user: usize,
}Expand description
A MailboxStore implementation using sled for storage.
Fields
tree: Treeencryption: Option<StorageEncryption>max_storage_per_user: usizeImplementations
Sourceimpl SledMailboxStore
impl SledMailboxStore
Sourcepub fn new(
db: Db,
encryption: Option<StorageEncryption>,
max_storage_per_user: usize,
) -> Result<Self>
pub fn new( db: Db, encryption: Option<StorageEncryption>, max_storage_per_user: usize, ) -> Result<Self>
Creates a new SledMailboxStore.
Arguments
db- Thesled::Dbinstance to use for storage.encryption- The optionalStorageEncryptionto use for encrypting messages.max_storage_per_user- The maximum number of messages to store per user.
Errors
This function will return an error if the mailbox tree cannot be opened.
Sourcepub(crate) fn make_message_key(
&self,
recipient_hash: &[u8; 32],
msg_id: &Uuid,
) -> Vec<u8> ⓘ
pub(crate) fn make_message_key( &self, recipient_hash: &[u8; 32], msg_id: &Uuid, ) -> Vec<u8> ⓘ
Creates a unique key for a message in the mailbox.
Sourcepub(crate) fn serialize_message(
&self,
msg: &EncryptedMessage,
) -> Result<Vec<u8>>
pub(crate) fn serialize_message( &self, msg: &EncryptedMessage, ) -> Result<Vec<u8>>
Serializes an EncryptedMessage and encrypts it if encryption is enabled.
Sourcepub(crate) fn deserialize_message(
&self,
data: &[u8],
) -> Result<EncryptedMessage>
pub(crate) fn deserialize_message( &self, data: &[u8], ) -> Result<EncryptedMessage>
Decrypts and deserializes an EncryptedMessage.